#
# spec file for package rpma
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rpma
%define lname   librpma0
Version:        1.3.0
Release:        1.3
Summary:        Remote Persistent Memory Access
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            http://pmem.io/pmdk/
Source:         https://github.com/pmem/rpma/archive/%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  libibverbs-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libpmem) >= 1.6
ExclusiveArch:  x86_64 aarch64 ppc64le

%description
librpma is a C library for accessing persistent memory (PMem) devices on
remote hosts over Remote Direct Memory Access (RDMA).

%package -n %{lname}
Summary:        Remote Persistent Memory Access
Group:          System/Libraries

%description -n %{lname}
librpma is a C library for accessing persistent memory (PMem) devices on
remote hosts over Remote Direct Memory Access (RDMA).

The librpma library provides two possible schemes of operation:
Remote Memory Access and Messaging. Both of them are available over a connection
established between two peers. Both of these schemes can make use of PMem as
well as DRAM for the sake of building
Remote Persistent Memory Accessing (RPMA) applications.

%package devel
Summary:        Development files for librpma
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
Development files for librpma

%prep
%autosetup -p1

%build
%cmake -DBUILD_TESTS=OFF
%cmake_build

%install
%cmake_install
# Fix install dir for cmake files
mkdir -p %{buildroot}/%{_libdir}/cmake/librpma
mv  %{buildroot}/%{_libdir}/librpma/cmake/*.cmake %{buildroot}/%{_libdir}/cmake/librpma

%post -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %{lname}
%{_libdir}/librpma.so.*
%license LICENSE

%files devel
%doc CHANGELOG.md
%{_includedir}/*.h
%{_libdir}/*.so
%{_libdir}/cmake/librpma
%{_libdir}/pkgconfig/*.pc

%changelog
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.0:
  * the native flush support (required support in the kernel and
    in an RNIC's driver)
  * missing unit tests for rpma_mr_atomic_write()
  * a check if librpma uses rdma-core installed from sources
  * BUILD_FORCE_ODP_NOT_SUPPORTED CMake option to disable On-
    Demand Paging (ODP) support in libibverbs
  * BUILD_FORCE_NATIVE_ATOMIC_WRITE_NOT_SUPPORTED CMake option to
    disable support for native atomic write in libibverbs
  * BUILD_FORCE_NATIVE_FLUSH_NOT_SUPPORTED CMake option to
    disable support for the native flush in libibverbs
  * the "ibv_query_device_ex_mock undeclared" compiler error when
    both ON_DEMAND_PAGING_SUPPORTED and
    NATIVE_ATOMIC_WRITE_SUPPORTED are not defined
  * renamed IBV_WR_ATOMIC_WRITE_SUPPORTED to
    NATIVE_ATOMIC_WRITE_SUPPORTED
  * renamed is_ibv_wr_atomic_write_supported() to
    is_ibv_atomic_write_supported()
  * updated the install-pmdk.sh script to install PMDK
    1.12.1-119-g8074b19b1 with fixes required for Rocky Linux 8
    and 9 and verify if the installation succeeded
  * rpma_peer_new() to check the native flush support in kernel
  * rpma_peer_setup_qp() to enable the native flush if both
    kernel and libibverbs support it
  * rpma_peer_usage2access() to return native access flags if
    both kernel and libibverbs support the native flush
  * rpma_flush() to use the native flush if the created QP
    supports it
* Sat Jan 28 2023 Dirk Müller <dmueller@suse.com>
- update to 1.2.0:
  * native atomic write support (required support in the kernel and in an
    RNIC's driver)
  * security warnings to the documentation of the following functions of the
    API:
  - rpma_conn_get_private_data()
  - rpma_conn_req_get_private_data()
  - rpma_mr_get_descriptor()
  - rpma_mr_remote_from_descriptor()
  - rpma_peer_cfg_from_descriptor()
  - rpma_peer_cfg_get_descriptor()
  * offset of the beginning of the used persistent memory in the clients
    using PMem in the examples
  * CI Coverity build run once a day over the night
  * a check for the native atomic write support in libibverbs
  * DEVELOPMENT.md file - `CMAKE_BUILD_TYPE` must be set to `Debug` when
    running the tests
  * check-headers.sh file - corrected the path of check-ms-license.pl and
    removed unneeded '*' at the start of the grep expressions
  * (examples) use HELLO_STR_SIZE instead of KILOBYTE in case of the hello
    string the common_pmem_map_file_with_signature_check() function in examples
  * `wr` passed to ibv_post_send(), ibv_post_recv() and ibv_post_srq_recv()
    is initialized to 0
  * `sge` passed to a log message (in rpma_mr_*() functions) is initialized
    to 0
  * `rq_size` in rpma_peer_create_srq() initialized to 0
  * detecting no free slot for a new connection request in example 13
  * memory allocations in example 07
  * minor issues detected by Coverity
  * sleep(1) added to mtt_client_connect() before the next connection retry
  * the default 'master' branch has been renamed to 'main'
  * logging of the source and the destination GID addresses in
    rpma_conn_req_new_from_id()
  has been restricted to only one case when CMAKE_BUILD_TYPE is set to 'Debug'
  * rpma_peer_new() to check the native atomic write support in kernel
  * rpma_peer_setup_qp() to enable native atomic write if both kernel and
    libibverbs supported it
  * rpma_mr_atomic_write() to use native atomic write if the created QP
    supported it
  * only the labeled (latest/stable/rolling etc.) versions of docker images
    (if available) are used in CI - it makes the CI self-updating
  * common source code of GPSMP examples moved to one folder
  * changed size of the read-after-write (RAW) buffer in the example 04
  * (examples) changed the write size from KILOBYTE to HELLO_STR_SIZE
  * unified coding style in the source, the test and the example files
  * DEVELOPMENT.md file containing the most important information needed
    during development of the library
  * THREAD_SAFETY.md file containing the analysis of thread safety of the
    librpma library
  * logging of the source and the destination GID addresses in
    rpma_conn_req_new_from_id()
  * error message for RPMA_E_AGAIN: "Temporary error, try again"
  * peer_cfg: get/set_direct_write_to_pmem and get_descriptor are now
    thread-safe
  * conn_cfg: all get and set functions for cq, rq, sq, rcq, timeout and
    compl_channel are now thread-safe
  * multi-threaded tests:
  - rpma_conn_apply_remote_peer_cfg
  - rpma_conn_cfg_get_srq
  - rpma_conn_cfg_set_srq
  - rpma_conn_req_connect
  - rpma_ep_next_conn_req
  - rpma_log_set_function
  - rpma_log_set_get_threshold
  - rpma_log_set_threshold
  - rpma_peer_cfg_set_direct_write_to_pmem
  - rpma_srq_cfg_new
  - rpma_srq_cfg_get_rcq_size
  - rpma_srq_cfg_get_rq_size
  - rpma_srq_cfg_set_rcq_size
  - rpma_srq_cfg_set_rq_size
  - rpma_srq_delete
  - rpma_srq_get_rcq
  - rpma_srq_new
  - rpma_cq_wait - returns RPMA_E_SHARED_CHANNEL if the completion channel is shared
  * Renamed CMake variables:
  - COVERAGE to TESTS_COVERAGE
  - DEVELOPER_MODE to BUILD_DEVELOPER_MODE
  - TEST_PYTHON_TOOLS to TESTS_PERF_TOOLS
  - TRACE_TESTS to TESTS_VERBOSE_OUTPUT
  - USE_ASAN to DEBUG_USE_ASAN
  - USE_UBSAN to DEBUG_USE_UBSAN
  * Changed default values of CMake variables:
  - CMAKE_BUILD_TYPE from Debug to Release
  - TESTS_PERF_TOOLS - from ON to OFF
* Fri Jan 22 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable aarch64 build
* Tue Oct 13 2020 Jan Engelhardt <jengelh@inai.de>
- Trim marketing wording from descriptions.
* Mon Oct 12 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Initial packaging of v0.9.0 (jsc#SLE-14102)
